@@ -1,11 +1,12 @@
 
-
+dfm <- makedfm()
+cmdfm <- collectMetadata(dfm)
 
 test_that("collectMetadata() works", {
-  expect_true(is.list(collectMetadata(dfm)))
-  
-  expect_equal(names(collectMetadata(dfm)), names(dfm))
-  
+  expect_true(is.list(cmdfm))
+
+  expect_equal(length(cmdfm) - 1, ncol(dfm))
+
   expect_true(is.list(collectMetadata(
     cbind(
       dfm,
@@ -18,6 +19,6 @@ test_that("collectMetadata() works", {
   )))
 
   expect_error(collectMetadata(data.frame(x = 1:5)))
-  
+
   expect_error(collectMetadata(list(1:5)))
 })
